/* elementary-calendar.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __CORE_ELEMENTARY_CALENDAR_H__
#define __CORE_ELEMENTARY_CALENDAR_H__

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <libedataserver/libedataserver.h>
#include <gee.h>
#include <gio/gio.h>
#include <gtk/gtk.h>
#include <libecal/libecal.h>
#include <libical-glib/libical-glib.h>
#include <gdk/gdk.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define BUILD_APP_NAME "Calendar"
#define BUILD_EXEC_NAME "io.elementary.calendar"
#define BUILD_PLUGIN_DIR "/usr/lib/io.elementary.calendar/plugins"

#define MAYA_TYPE_BACKEND (maya_backend_get_type ())
#define MAYA_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MAYA_TYPE_BACKEND, MayaBackend))
#define MAYA_IS_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MAYA_TYPE_BACKEND))
#define MAYA_BACKEND_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), MAYA_TYPE_BACKEND, MayaBackendIface))

typedef struct _MayaBackend MayaBackend;
typedef struct _MayaBackendIface MayaBackendIface;

#define MAYA_TYPE_PLACEMENT_WIDGET (maya_placement_widget_get_type ())
#define MAYA_PLACEMENT_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MAYA_TYPE_PLACEMENT_WIDGET, MayaPlacementWidget))
#define MAYA_PLACEMENT_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MAYA_TYPE_PLACEMENT_WIDGET, MayaPlacementWidgetClass))
#define MAYA_IS_PLACEMENT_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MAYA_TYPE_PLACEMENT_WIDGET))
#define MAYA_IS_PLACEMENT_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MAYA_TYPE_PLACEMENT_WIDGET))
#define MAYA_PLACEMENT_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MAYA_TYPE_PLACEMENT_WIDGET, MayaPlacementWidgetClass))

typedef struct _MayaPlacementWidget MayaPlacementWidget;
typedef struct _MayaPlacementWidgetClass MayaPlacementWidgetClass;

#define MAYA_TYPE_BACKENDS_MANAGER (maya_backends_manager_get_type ())
#define MAYA_BACKENDS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MAYA_TYPE_BACKENDS_MANAGER, MayaBackendsManager))
#define MAYA_BACKENDS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MAYA_TYPE_BACKENDS_MANAGER, MayaBackendsManagerClass))
#define MAYA_IS_BACKENDS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MAYA_TYPE_BACKENDS_MANAGER))
#define MAYA_IS_BACKENDS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MAYA_TYPE_BACKENDS_MANAGER))
#define MAYA_BACKENDS_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MAYA_TYPE_BACKENDS_MANAGER, MayaBackendsManagerClass))

typedef struct _MayaBackendsManager MayaBackendsManager;
typedef struct _MayaBackendsManagerClass MayaBackendsManagerClass;
typedef struct _MayaBackendsManagerPrivate MayaBackendsManagerPrivate;

#define MAYA_TYPE_LOCAL_BACKEND (maya_local_backend_get_type ())
#define MAYA_LOCAL_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MAYA_TYPE_LOCAL_BACKEND, MayaLocalBackend))
#define MAYA_LOCAL_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MAYA_TYPE_LOCAL_BACKEND, MayaLocalBackendClass))
#define MAYA_IS_LOCAL_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MAYA_TYPE_LOCAL_BACKEND))
#define MAYA_IS_LOCAL_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MAYA_TYPE_LOCAL_BACKEND))
#define MAYA_LOCAL_BACKEND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MAYA_TYPE_LOCAL_BACKEND, MayaLocalBackendClass))

typedef struct _MayaLocalBackend MayaLocalBackend;
typedef struct _MayaLocalBackendClass MayaLocalBackendClass;
typedef struct _MayaLocalBackendPrivate MayaLocalBackendPrivate;
typedef struct _MayaPlacementWidgetPrivate MayaPlacementWidgetPrivate;

#define CALENDAR_TYPE_EVENT_STORE (calendar_event_store_get_type ())
#define CALENDAR_EVENT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CALENDAR_TYPE_EVENT_STORE, CalendarEventStore))
#define CALENDAR_EVENT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CALENDAR_TYPE_EVENT_STORE, CalendarEventStoreClass))
#define CALENDAR_IS_EVENT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CALENDAR_TYPE_EVENT_STORE))
#define CALENDAR_IS_EVENT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CALENDAR_TYPE_EVENT_STORE))
#define CALENDAR_EVENT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CALENDAR_TYPE_EVENT_STORE, CalendarEventStoreClass))

typedef struct _CalendarEventStore CalendarEventStore;
typedef struct _CalendarEventStoreClass CalendarEventStoreClass;
typedef struct _CalendarEventStorePrivate CalendarEventStorePrivate;

#define CALENDAR_UTIL_TYPE_DATE_RANGE (calendar_util_date_range_get_type ())
#define CALENDAR_UTIL_DATE_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CALENDAR_UTIL_TYPE_DATE_RANGE, CalendarUtilDateRange))
#define CALENDAR_UTIL_DATE_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CALENDAR_UTIL_TYPE_DATE_RANGE, CalendarUtilDateRangeClass))
#define CALENDAR_UTIL_IS_DATE_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CALENDAR_UTIL_TYPE_DATE_RANGE))
#define CALENDAR_UTIL_IS_DATE_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CALENDAR_UTIL_TYPE_DATE_RANGE))
#define CALENDAR_UTIL_DATE_RANGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CALENDAR_UTIL_TYPE_DATE_RANGE, CalendarUtilDateRangeClass))

typedef struct _CalendarUtilDateRange CalendarUtilDateRange;
typedef struct _CalendarUtilDateRangeClass CalendarUtilDateRangeClass;

#define CALENDAR_TYPE_TIME_MANAGER (calendar_time_manager_get_type ())
#define CALENDAR_TIME_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CALENDAR_TYPE_TIME_MANAGER, CalendarTimeManager))
#define CALENDAR_TIME_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CALENDAR_TYPE_TIME_MANAGER, CalendarTimeManagerClass))
#define CALENDAR_IS_TIME_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CALENDAR_TYPE_TIME_MANAGER))
#define CALENDAR_IS_TIME_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CALENDAR_TYPE_TIME_MANAGER))
#define CALENDAR_TIME_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CALENDAR_TYPE_TIME_MANAGER, CalendarTimeManagerClass))

typedef struct _CalendarTimeManager CalendarTimeManager;
typedef struct _CalendarTimeManagerClass CalendarTimeManagerClass;
typedef struct _CalendarTimeManagerPrivate CalendarTimeManagerPrivate;

#define CALENDAR_UTIL_TYPE_DATE_ITERATOR (calendar_util_date_iterator_get_type ())
#define CALENDAR_UTIL_DATE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CALENDAR_UTIL_TYPE_DATE_ITERATOR, CalendarUtilDateIterator))
#define CALENDAR_UTIL_DATE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CALENDAR_UTIL_TYPE_DATE_ITERATOR, CalendarUtilDateIteratorClass))
#define CALENDAR_UTIL_IS_DATE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CALENDAR_UTIL_TYPE_DATE_ITERATOR))
#define CALENDAR_UTIL_IS_DATE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CALENDAR_UTIL_TYPE_DATE_ITERATOR))
#define CALENDAR_UTIL_DATE_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CALENDAR_UTIL_TYPE_DATE_ITERATOR, CalendarUtilDateIteratorClass))

typedef struct _CalendarUtilDateIterator CalendarUtilDateIterator;
typedef struct _CalendarUtilDateIteratorClass CalendarUtilDateIteratorClass;
typedef struct _CalendarUtilDateIteratorPrivate CalendarUtilDateIteratorPrivate;
typedef struct _CalendarUtilDateRangePrivate CalendarUtilDateRangePrivate;

struct _MayaBackendIface {
	GTypeInterface parent_iface;
	gchar* (*get_name) (MayaBackend* self);
	gchar* (*get_uid) (MayaBackend* self);
	GeeCollection* (*get_new_calendar_widget) (MayaBackend* self, ESource* to_edit);
	void (*add_new_calendar) (MayaBackend* self, const gchar* name, const gchar* color, gboolean set_default, GeeCollection* widgets);
	void (*modify_calendar) (MayaBackend* self, const gchar* name, const gchar* color, gboolean set_default, GeeCollection* widgets, ESource* source);
};

struct _MayaBackendsManager {
	GObject parent_instance;
	MayaBackendsManagerPrivate * priv;
	GeeArrayList* backends;
};

struct _MayaBackendsManagerClass {
	GObjectClass parent_class;
};

struct _MayaLocalBackend {
	GObject parent_instance;
	MayaLocalBackendPrivate * priv;
};

struct _MayaLocalBackendClass {
	GObjectClass parent_class;
};

struct _MayaPlacementWidget {
	GObject parent_instance;
	MayaPlacementWidgetPrivate * priv;
	GtkWidget* widget;
	gint row;
	gint column;
	gchar* ref_name;
	gboolean needed;
};

struct _MayaPlacementWidgetClass {
	GObjectClass parent_class;
};

struct _CalendarEventStore {
	GObject parent_instance;
	CalendarEventStorePrivate * priv;
	GQueue* calendar_trash;
};

struct _CalendarEventStoreClass {
	GObjectClass parent_class;
};

struct _CalendarTimeManager {
	GObject parent_instance;
	CalendarTimeManagerPrivate * priv;
};

struct _CalendarTimeManagerClass {
	GObjectClass parent_class;
};

struct _CalendarUtilDateIterator {
	GObject parent_instance;
	CalendarUtilDateIteratorPrivate * priv;
};

struct _CalendarUtilDateIteratorClass {
	GObjectClass parent_class;
};

struct _CalendarUtilDateRange {
	GObject parent_instance;
	CalendarUtilDateRangePrivate * priv;
};

struct _CalendarUtilDateRangeClass {
	GObjectClass parent_class;
};

VALA_EXTERN GType maya_placement_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MayaPlacementWidget, g_object_unref)
VALA_EXTERN GType maya_backend_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MayaBackend, g_object_unref)
VALA_EXTERN gchar* maya_backend_get_name (MayaBackend* self);
VALA_EXTERN gchar* maya_backend_get_uid (MayaBackend* self);
VALA_EXTERN GeeCollection* maya_backend_get_new_calendar_widget (MayaBackend* self,
                                                     ESource* to_edit);
VALA_EXTERN void maya_backend_add_new_calendar (MayaBackend* self,
                                    const gchar* name,
                                    const gchar* color,
                                    gboolean set_default,
                                    GeeCollection* widgets);
VALA_EXTERN void maya_backend_modify_calendar (MayaBackend* self,
                                   const gchar* name,
                                   const gchar* color,
                                   gboolean set_default,
                                   GeeCollection* widgets,
                                   ESource* source);
VALA_EXTERN GType maya_backends_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MayaBackendsManager, g_object_unref)
VALA_EXTERN MayaBackendsManager* maya_backends_manager_get_default (void);
VALA_EXTERN void maya_backends_manager_add_backend (MayaBackendsManager* self,
                                        MayaBackend* b);
VALA_EXTERN void maya_backends_manager_remove_backend (MayaBackendsManager* self,
                                           MayaBackend* b);
VALA_EXTERN GType maya_local_backend_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MayaLocalBackend, g_object_unref)
VALA_EXTERN void maya_local_backend_add_source (MayaLocalBackend* self,
                                    ESource* new_source,
                                    gboolean set_default,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN void maya_local_backend_add_source_finish (MayaLocalBackend* self,
                                           GAsyncResult* _res_);
VALA_EXTERN void maya_local_backend_set_source_default (MayaLocalBackend* self,
                                            ESource* source,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
VALA_EXTERN void maya_local_backend_set_source_default_finish (MayaLocalBackend* self,
                                                   GAsyncResult* _res_);
VALA_EXTERN MayaLocalBackend* maya_local_backend_new (void);
VALA_EXTERN MayaLocalBackend* maya_local_backend_construct (GType object_type);
VALA_EXTERN MayaPlacementWidget* maya_placement_widget_new (void);
VALA_EXTERN MayaPlacementWidget* maya_placement_widget_construct (GType object_type);
VALA_EXTERN GeeLinkedList* maya_default_placement_widgets_get_user (gint row,
                                                        gboolean needed,
                                                        const gchar* entry_text,
                                                        const gchar* ph_text);
VALA_EXTERN GeeLinkedList* maya_default_placement_widgets_get_email (gint row,
                                                         gboolean needed,
                                                         const gchar* entry_text,
                                                         const gchar* ph_text);
VALA_EXTERN MayaPlacementWidget* maya_default_placement_widgets_get_keep_copy (gint row,
                                                                   gboolean default_value);
VALA_EXTERN GType calendar_event_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CalendarEventStore, g_object_unref)
VALA_EXTERN CalendarEventStore* calendar_event_store_get_default (void);
VALA_EXTERN CalendarEventStore* calendar_event_store_new (void);
VALA_EXTERN CalendarEventStore* calendar_event_store_construct (GType object_type);
VALA_EXTERN void calendar_event_store_open (CalendarEventStore* self,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN void calendar_event_store_open_finish (CalendarEventStore* self,
                                       GAsyncResult* _res_);
VALA_EXTERN void calendar_event_store_add_event (CalendarEventStore* self,
                                     ESource* source,
                                     ECalComponent* event);
VALA_EXTERN gboolean calendar_event_store_calclient_is_readonly (CalendarEventStore* self,
                                                     ESource* source);
VALA_EXTERN void calendar_event_store_update_event (CalendarEventStore* self,
                                        ESource* source,
                                        ECalComponent* event,
                                        ECalObjModType mod_type);
VALA_EXTERN void calendar_event_store_remove_event (CalendarEventStore* self,
                                        ESource* source,
                                        ECalComponent* event,
                                        ECalObjModType mod_type);
VALA_EXTERN void calendar_event_store_trash_calendar (CalendarEventStore* self,
                                          ESource* source);
VALA_EXTERN void calendar_event_store_restore_calendar (CalendarEventStore* self);
VALA_EXTERN void calendar_event_store_delete_trashed_calendars (CalendarEventStore* self);
VALA_EXTERN void calendar_event_store_change_month (CalendarEventStore* self,
                                        gint relative);
VALA_EXTERN void calendar_event_store_change_year (CalendarEventStore* self,
                                       gint relative);
VALA_EXTERN void calendar_event_store_load_all_sources (CalendarEventStore* self);
VALA_EXTERN void calendar_event_store_add_source (CalendarEventStore* self,
                                      ESource* source);
VALA_EXTERN void calendar_event_store_remove_source (CalendarEventStore* self,
                                         ESource* source);
VALA_EXTERN GeeCollection* calendar_event_store_get_events (CalendarEventStore* self);
VALA_EXTERN GType calendar_util_date_range_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CalendarUtilDateRange, g_object_unref)
VALA_EXTERN CalendarUtilDateRange* calendar_event_store_get_data_range (CalendarEventStore* self);
VALA_EXTERN CalendarUtilDateRange* calendar_event_store_get_month_range (CalendarEventStore* self);
VALA_EXTERN ESourceRegistry* calendar_event_store_get_registry (CalendarEventStore* self);
VALA_EXTERN GDateTime* calendar_event_store_get_month_start (CalendarEventStore* self);
VALA_EXTERN void calendar_event_store_set_month_start (CalendarEventStore* self,
                                           GDateTime* value);
VALA_EXTERN gint calendar_event_store_get_num_weeks (CalendarEventStore* self);
VALA_EXTERN GDateWeekday calendar_event_store_get_week_starts_on (CalendarEventStore* self);
VALA_EXTERN void calendar_event_store_set_week_starts_on (CalendarEventStore* self,
                                              GDateWeekday value);
VALA_EXTERN ECalComponent* calendar_event_store_get_drag_component (CalendarEventStore* self);
VALA_EXTERN void calendar_event_store_set_drag_component (CalendarEventStore* self,
                                              ECalComponent* value);
VALA_EXTERN GType calendar_time_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CalendarTimeManager, g_object_unref)
VALA_EXTERN CalendarTimeManager* calendar_time_manager_get_default (void);
VALA_EXTERN CalendarTimeManager* calendar_time_manager_setup_test (ICalTimezone* system_timezone);
VALA_EXTERN ICalTimezone* calendar_time_manager_get_system_timezone (CalendarTimeManager* self);
VALA_EXTERN GType calendar_util_date_iterator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CalendarUtilDateIterator, g_object_unref)
VALA_EXTERN CalendarUtilDateIterator* calendar_util_date_iterator_new (CalendarUtilDateRange* range);
VALA_EXTERN CalendarUtilDateIterator* calendar_util_date_iterator_construct (GType object_type,
                                                                 CalendarUtilDateRange* range);
VALA_EXTERN GDateTime* calendar_util_date_iterator_get_current (CalendarUtilDateIterator* self);
VALA_EXTERN void calendar_util_date_iterator_set_current (CalendarUtilDateIterator* self,
                                              GDateTime* value);
VALA_EXTERN CalendarUtilDateRange* calendar_util_date_iterator_get_range (CalendarUtilDateIterator* self);
VALA_EXTERN CalendarUtilDateRange* calendar_util_date_range_new (GDateTime* first,
                                                     GDateTime* last);
VALA_EXTERN CalendarUtilDateRange* calendar_util_date_range_construct (GType object_type,
                                                           GDateTime* first,
                                                           GDateTime* last);
VALA_EXTERN gboolean calendar_util_date_range_equals (CalendarUtilDateRange* self,
                                          CalendarUtilDateRange* other);
VALA_EXTERN GeeList* calendar_util_date_range_to_list (CalendarUtilDateRange* self);
VALA_EXTERN GDateTime* calendar_util_date_range_get_first_dt (CalendarUtilDateRange* self);
VALA_EXTERN GDateTime* calendar_util_date_range_get_last_dt (CalendarUtilDateRange* self);
VALA_EXTERN gboolean calendar_util_datetime_equal_func (GDateTime* a,
                                            GDateTime* b);
VALA_EXTERN gboolean calendar_util_datetime_is_all_day (GDateTime* dtstart,
                                            GDateTime* dtend);
VALA_EXTERN ICalTime* calendar_util_datetimes_to_icaltime (GDateTime* date,
                                               GDateTime* time_local,
                                               ICalTimezone* timezone);
VALA_EXTERN GDateTime* calendar_util_datetime_get_start_of_month (GDateTime* date);
VALA_EXTERN GDateTime* calendar_util_datetime_strip_time (GDateTime* datetime);
VALA_EXTERN gboolean calendar_util_ecalcomponent_equal_func (ECalComponent* a,
                                                 ECalComponent* b);
VALA_EXTERN gint calendar_util_ecalcomponent_compare_func (ECalComponent* a,
                                               ECalComponent* b);
VALA_EXTERN gboolean calendar_util_ecalcomponent_is_on_day (ECalComponent* component,
                                                GDateTime* day);
VALA_EXTERN void calendar_util_icalcomponent_get_icaltimes (ICalComponent* component,
                                                ICalTime** dt_start,
                                                ICalTime** dt_end);
VALA_EXTERN void calendar_util_icalcomponent_get_local_datetimes (ICalComponent* component,
                                                      GDateTime** start_date,
                                                      GDateTime** end_date);
VALA_EXTERN void calendar_util_icalcomponent_get_datetimes (ICalComponent* component,
                                                GDateTime** start_date,
                                                GDateTime** end_date);
VALA_EXTERN void calendar_util_icalcomponent_get_local_datetimes_for_display (ICalComponent* component,
                                                                  GDateTime** start_date,
                                                                  GDateTime** end_date);
VALA_EXTERN void calendar_util_icalcomponent_get_datetimes_for_display (ICalComponent* component,
                                                            GDateTime** start_date,
                                                            GDateTime** end_date);
VALA_EXTERN gboolean calendar_util_icalcomponent_is_in_range (ICalComponent* component,
                                                  CalendarUtilDateRange* range);
VALA_EXTERN gboolean calendar_util_icalcomponent_is_multiday (ICalComponent* component);
VALA_EXTERN GTimeZone* calendar_util_icaltime_get_timezone (ICalTime* date);
VALA_EXTERN GDateTime* calendar_util_icaltime_to_datetime (ICalTime* date);
VALA_EXTERN GDateTime* calendar_util_icaltime_to_local_datetime (ICalTime* date);
VALA_EXTERN ICalTime* calendar_util_icaltime_convert_to_local (ICalTime* time);
VALA_EXTERN gint maya_util_compare_events (ECalComponent* comp1,
                               ECalComponent* comp2);
VALA_EXTERN gchar* maya_util_get_source_location (ESource* source);
VALA_EXTERN void maya_util_save_temp_selected_calendars (void);
VALA_EXTERN ECalComponent* maya_util_copy_ecal_component (ECalComponent* original);
VALA_EXTERN gchar* maya_util_mangle_uid (const gchar* original_uid);
VALA_EXTERN gboolean maya_gestures_utils_on_scroll_event (GdkEventScroll* event);
VALA_EXTERN void maya_gestures_utils_reset_timer (GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN void maya_gestures_utils_reset_timer_finish (GAsyncResult* _res_);

G_END_DECLS

#endif
