/* web.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __PLUGINS_WEB_WEB_H__
#define __PLUGINS_WEB_WEB_H__

#include <gmodule.h>
#include "elementary-calendar.h"
#include <glib-object.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define MAYA_TYPE_WEB_BACKEND (maya_web_backend_get_type ())
#define MAYA_WEB_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MAYA_TYPE_WEB_BACKEND, MayaWebBackend))
#define MAYA_WEB_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MAYA_TYPE_WEB_BACKEND, MayaWebBackendClass))
#define MAYA_IS_WEB_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MAYA_TYPE_WEB_BACKEND))
#define MAYA_IS_WEB_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MAYA_TYPE_WEB_BACKEND))
#define MAYA_WEB_BACKEND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MAYA_TYPE_WEB_BACKEND, MayaWebBackendClass))

typedef struct _MayaWebBackend MayaWebBackend;
typedef struct _MayaWebBackendClass MayaWebBackendClass;
typedef struct _MayaWebBackendPrivate MayaWebBackendPrivate;

struct _MayaWebBackend {
	GObject parent_instance;
	MayaWebBackendPrivate * priv;
};

struct _MayaWebBackendClass {
	GObjectClass parent_class;
};

VALA_EXTERN MayaBackend* get_backend (GModule* module);
VALA_EXTERN GType maya_web_backend_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MayaWebBackend, g_object_unref)
VALA_EXTERN MayaWebBackend* maya_web_backend_new (void);
VALA_EXTERN MayaWebBackend* maya_web_backend_construct (GType object_type);

G_END_DECLS

#endif
